//+------------------------------------------------------------------+
//|                                               Stochastic_Bar.mq4 |
//|                               Copyright  2014, Gehtsoft USA LLC |
//|                                            http://fxcodebase.com |
//|                            fixed and added alerts/arrows mrtools |
//+------------------------------------------------------------------+
#property copyright "Copyright  2014, Gehtsoft USA LLC"
#property link      "http://fxcodebase.com"

#property indicator_separate_window
#property indicator_buffers 2
#property indicator_color1  Lime
#property indicator_color2  Red
#property indicator_minimum 0
#property indicator_maximum 100

//
//
//
//
//

extern int    Kperiod          = 5;
extern int    Dperiod          = 3;
extern int    slowing          = 3;
extern int    Method           = 1;  // 0 - SMA, 1 - EMA, 2 - SMMA,3 - LWMA
extern int    Price_Field      = 0;  // 0 - Low/High, 1 - Close/Close 
extern double OverBoughtLevel  = 80;
extern double OverSoldLevel    = 20; 

extern bool   alertsOn         = true;
extern bool   alertsOnCurrent  = true;
extern bool   alertsMessage    = true;
extern bool   alertsSound      = false;
extern bool   alertsNotify     = true;
extern bool   alertsEmail      = true;
extern string soundFile        = "alert2.wav"; 

extern bool   ShowArrows       = true;
extern string arrowsIdentifier = "StochBar arrows1";
extern double arrowsUpperGap   = 1.0;
extern double arrowsLowerGap   = 1.0;
extern color  arrowsUpColor    = Lime;
extern color  arrowsDnColor    = Orange;                      

//
//
//
//
//

double H2[];
double H4[];
double trend[];

//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+
//
//
//
//
//

int init()
{
   IndicatorBuffers(3);
   SetIndexBuffer(0,H2); SetIndexStyle(0,DRAW_HISTOGRAM);
   SetIndexBuffer(1,H4); SetIndexStyle(1,DRAW_HISTOGRAM);
   SetIndexBuffer(2,trend);
   SetLevelValue(0,OverBoughtLevel);
   SetLevelValue(1,OverSoldLevel);
   IndicatorShortName("Stochastic Bar");
return(0);
}
int deinit()
{ 
   deleteArrows();  
return(0);
}

//
//
//
//
//

int start()
{
   int counted_bars=IndicatorCounted();
   int i,limit;
   
   if(counted_bars < 0) return(-1);
   if(counted_bars > 0) counted_bars--;
           limit = MathMin(Bars-counted_bars,Bars-1); 
   
   //
   //
   //
   //
   //
   
   for (i=limit; i>=0; i--)
   {
      double K = iStochastic(NULL, 0, Kperiod, Dperiod, slowing, Method, Price_Field, MODE_MAIN,i);
      double D = iStochastic(NULL, 0, Kperiod, Dperiod, slowing, Method, Price_Field, MODE_SIGNAL,i);
  
         H2[i] = EMPTY_VALUE;
         H4[i] = EMPTY_VALUE;
         trend[i] = 0;
         if (K>D && K<OverBoughtLevel) trend[i] = 1;
         if (K<D && K>OverSoldLevel)   trend[i] =-1; 
         if (trend[i] == 1)  H2[i]=100; 
         if (trend[i] ==-1)  H4[i]=100; 
      
         //
         //
         //
         //
         //
         
         if (ShowArrows)
         {
            deleteArrow(Time[i]);
            if (trend[i]!=trend[i+1])
            {
              if (trend[i] == 1) drawArrow(i,arrowsUpColor,241,false);
              if (trend[i] ==-1) drawArrow(i,arrowsDnColor,242,true);
            }
         }
   
   }
   
   //
   //
   //
   //
   //
   
   if (alertsOn)
   {
      if (alertsOnCurrent)
           int whichBar = 0;
      else     whichBar = 1; 
      if (trend[whichBar] != trend[whichBar+1])
      if (trend[whichBar] == 1)
            doAlert("up");
      else  doAlert("down");       
   }
return(0);
}     
 
//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+  
//
//
//
//
//

void doAlert(string doWhat)
{
   static string   previousAlert="nothing";
   static datetime previousTime;
   string message;
   
      if (previousAlert != doWhat || previousTime != Time[0]) {
          previousAlert  = doWhat;
          previousTime   = Time[0];

          //
          //
          //
          //
          //

          message =  StringConcatenate(Symbol()," at ",TimeToStr(TimeLocal(),TIME_SECONDS)," Stochastic Bar ",doWhat);
             if (alertsMessage) Alert(message);
             if (alertsNotify)  SendNotification(message);
             if (alertsEmail)   SendMail(StringConcatenate(Symbol()," Stochastic Bar "),message);
             if (alertsSound)   PlaySound("alert2.wav");
      }
}

//
//
//
//
//

void drawArrow(int i,color theColor,int theCode,bool up)
{
   string name = arrowsIdentifier+":"+Time[i];
   double gap  = iATR(NULL,0,20,i);   
   
      //
      //
      //
      //
      //
      
      ObjectCreate(name,OBJ_ARROW,0,Time[i],0);
         ObjectSet(name,OBJPROP_ARROWCODE,theCode);
         ObjectSet(name,OBJPROP_COLOR,theColor);
  
         if (up)
               ObjectSet(name,OBJPROP_PRICE1,High[i] + arrowsUpperGap * gap);
         else  ObjectSet(name,OBJPROP_PRICE1,Low[i]  - arrowsLowerGap * gap);
}

//
//
//
//
//

void deleteArrows()
{
   string lookFor       = arrowsIdentifier+":";
   int    lookForLength = StringLen(lookFor);
   for (int i=ObjectsTotal()-1; i>=0; i--)
   {
      string objectName = ObjectName(i);
         if (StringSubstr(objectName,0,lookForLength) == lookFor) ObjectDelete(objectName);
   }
}

//
//
//
//
//

void deleteArrow(datetime time)
{
   string lookFor = arrowsIdentifier+":"+time; ObjectDelete(lookFor);
}






